Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InputBuffer ¶
type InputBuffer struct {
// contains filtered or unexported fields
}
InputBuffer represents a buffer for storing input data.
func NewInputBuffer ¶
func NewInputBuffer() *InputBuffer
NewInputBuffer creates a new InputBuffer instance.
func (*InputBuffer) GetContents ¶
func (ib *InputBuffer) GetContents() []byte
GetContents returns the contents of the buffer as a byte slice.
func (*InputBuffer) ReadFromString ¶
func (ib *InputBuffer) ReadFromString(inputString string) (int64, error)
ReadFrom reads input from the given reader and stores it in the buffer.
func (*InputBuffer) ToString ¶
func (ib *InputBuffer) ToString() string
ToString returns the contents of the buffer as a string.
Click to show internal directories.
Click to hide internal directories.